@@ -137,7 +137,7 @@ BOOL CyclePort(int index)
 	DWORD size;
 	USB_CYCLE_PORT_PARAMS cycle_port;
 
-	if_not_assert(index < MAX_DRIVES)
+	if_assert_fails(index < MAX_DRIVES)
 		return -1;
 	// Wait at least 10 secs between resets
 	if (GetTickCount64() < LastReset + 10000ULL) {
@@ -191,7 +191,7 @@ int CycleDevice(int index)
 	SP_DEVINFO_DATA dev_info_data;
 	SP_PROPCHANGE_PARAMS propchange_params;
 
-	if_not_assert(index < MAX_DRIVES)
+	if_assert_fails(index < MAX_DRIVES)
 		return ERROR_INVALID_DRIVE;
 	if ((index < 0) || (safe_strlen(rufus_drive[index].id) < 8))
 		return ERROR_INVALID_PARAMETER;
@@ -419,8 +419,8 @@ BOOL GetOpticalMedia(IMG_SAVE* img_save)
 //#define FORCED_DEVICE
 #ifdef FORCED_DEVICE
 #define FORCED_VID 0x04E8
-#define FORCED_PID 0x61ED
-#define FORCED_NAME "Samsung uSD Card Reader USB Device"
+#define FORCED_PID 0x6300
+#define FORCED_NAME "Samsung Type-C USB Device"
 #endif
 
 void ClearDrives(void)
@@ -585,9 +585,9 @@ BOOL GetDevices(DWORD devnum)
 
 	// Better safe than sorry. And yeah, we could have used arrays of
 	// arrays to avoid this, but it's more readable this way.
-	if_not_assert((uasp_start > 0) && (uasp_start < ARRAYSIZE(usbstor_name)))
+	if_assert_fails((uasp_start > 0) && (uasp_start < ARRAYSIZE(usbstor_name)))
 		goto out;
-	if_not_assert((card_start > 0) && (card_start < ARRAYSIZE(genstor_name)))
+	if_assert_fails((card_start > 0) && (card_start < ARRAYSIZE(genstor_name)))
 		goto out;
 
 	devid_list = NULL;
@@ -675,7 +675,7 @@ BOOL GetDevices(DWORD devnum)
 				}
 				// Also test for "_SD&" instead of "_SD_" and so on to allow for devices like
 				// "SCSI\DiskRicoh_Storage_SD&REV_3.0" to be detected.
-				if_not_assert(strlen(scsi_card_name_copy) > 1)
+				if_assert_fails(strlen(scsi_card_name_copy) > 1)
 					continue;
 				scsi_card_name_copy[strlen(scsi_card_name_copy) - 1] = '&';
 				if (safe_strstr(buffer, scsi_card_name_copy) != NULL) {
@@ -768,7 +768,7 @@ BOOL GetDevices(DWORD devnum)
 					uuprintf("  Matched with (GP) ID[%03d]: %s", j, device_id);
 				}
 				if ((uintptr_t)htab_devid.table[j].data > 0) {
-					uuprintf("  Matched with Hub[%d]: '%s'", (uintptr_t)htab_devid.table[j].data,
+					uuprintf("  Matched with Hub[%llu]: '%s'", (uintptr_t)htab_devid.table[j].data,
 							dev_if_path.String[(uintptr_t)htab_devid.table[j].data]);
 					if (GetUSBProperties(dev_if_path.String[(uintptr_t)htab_devid.table[j].data], device_id, &props)) {
 						method_str = "";
@@ -927,9 +927,9 @@ BOOL GetDevices(DWORD devnum)
 				}
 				if ((!enable_HDDs) && (!props.is_VHD) && (!props.is_CARD) &&
 					((score = IsHDD(drive_index, (uint16_t)props.vid, (uint16_t)props.pid, buffer)) > 0)) {
-					uprintf("Device eliminated because it was detected as a Hard Drive (score %d > 0)", score);
+					uprintf("Device eliminated because it was detected as a Hard Drive or SSD (score %d > 0)", score);
 					if (!list_non_usb_removable_drives)
-						uprintf("If this device is not a Hard Drive, please e-mail the author of this application");
+						uprintf("If this device is not a Hard Drive or SSD, please e-mail the author of this application");
 					uprintf("NOTE: You can enable the listing of Hard Drives under 'advanced drive properties'");
 					safe_free(devint_detail_data);
 					break;
@@ -1007,7 +1007,7 @@ BOOL GetDevices(DWORD devnum)
 				rufus_drive[num_drives].display_name = safe_strdup(display_name);
 				rufus_drive[num_drives].label = safe_strdup(label);
 				rufus_drive[num_drives].size = drive_size;
-				if_not_assert(rufus_drive[num_drives].size != 0)
+				if_assert_fails(rufus_drive[num_drives].size != 0)
 					break;
 				if (hub_path != NULL) {
 					rufus_drive[num_drives].hub = safe_strdup(hub_path);
@@ -1015,7 +1015,7 @@ BOOL GetDevices(DWORD devnum)
 				}
 				num_drives++;
 				if (num_drives >= MAX_DRIVES)
-					uprintf("Warning: Found more than %d drives - ignoring remaining ones...", MAX_DRIVES);
+					uprintf("WARNING: Found more than %d drives - ignoring remaining ones...", MAX_DRIVES);
 				safe_free(devint_detail_data);
 				break;
 			}
