@@ -46,7 +46,7 @@
 #endif
 
 /* Define to 1 if you have the `ftruncate' function. */
-/* #undef HAVE_FTRUNCATE */
+#define HAVE_FTRUNCATE 1
 
 /* Define if you have the iconv() function and it works. */
 /* #undef HAVE_ICONV */
