@@ -261,7 +261,7 @@ const char* WinPKIErrorString(void)
 }
 
 // Mostly from https://support.microsoft.com/en-us/kb/323809
-char* GetSignatureName(const char* path, const char* country_code, BOOL bSilent)
+char* GetSignatureName(const char* path, const char* country_code, uint8_t* thumbprint, BOOL bSilent)
 {
 	static char szSubjectName[128];
 	char szCountry[3] = "__";
@@ -340,6 +340,16 @@ char* GetSignatureName(const char* path, const char* country_code, BOOL bSilent)
 		goto out;
 	}
 
+	// Get the thumbprint if requested
+	if (thumbprint != NULL) {
+		dwSize = SHA1_HASHSIZE;
+		if (!CryptHashCertificate(0, CALG_SHA1, 0, pCertContext->pbCertEncoded,
+			pCertContext->cbCertEncoded, thumbprint, &dwSize)) {
+			uprintf("PKI: Failed to compute the thumbprint: %s", WinPKIErrorString());
+			goto out;
+		}
+	}
+
 	// If a country code is provided, validate that the certificate we have is for the same country
 	if (country_code != NULL) {
 		dwSize = CertGetNameStringA(pCertContext, CERT_NAME_ATTR_TYPE, 0, szOID_COUNTRY_NAME,
@@ -696,7 +706,7 @@ uint64_t GetSignatureTimeStamp(const char* path)
 		uprintf("Note: '%s' has nested timestamp %s", (path==NULL)?mpath:path, TimestampToHumanReadable(nested_timestamp));
 	if ((timestamp != 0ULL) && (nested_timestamp != 0ULL)) {
 		if (_abs64(nested_timestamp - timestamp) > 100) {
-			uprintf("PKI: Signature timestamp and nested timestamp differ by more than a minute. "
+			uprintf("PKI: Signature timestamp (%lld) and nested timestamp (%lld) differ by more than a minute. "
 				"This could indicate something very nasty...", timestamp, nested_timestamp);
 			timestamp = 0ULL;
 		}
@@ -728,11 +738,11 @@ LONG ValidateSignature(HWND hDlg, const char* path)
 	// Check the signature name. Make it specific enough (i.e. don't simply check for "Akeo")
 	// so that, besides hacking our server, it'll place an extra hurdle on any malicious entity
 	// into also fooling a C.A. to issue a certificate that passes our test.
-	signature_name = GetSignatureName(path, cert_country, (hDlg == INVALID_HANDLE_VALUE));
+	signature_name = GetSignatureName(path, cert_country, NULL, (hDlg == INVALID_HANDLE_VALUE));
 	if (signature_name == NULL) {
 		uprintf("PKI: Could not get signature name");
 		if (hDlg != INVALID_HANDLE_VALUE)
-			MessageBoxExU(hDlg, lmprintf(MSG_284), lmprintf(MSG_283), MB_OK | MB_ICONERROR | MB_IS_RTL, selected_langid);
+			Notification(MB_OK | MB_ICONERROR, lmprintf(MSG_283), lmprintf(MSG_284));
 		return TRUST_E_NOSIGNATURE;
 	}
 	for (i = 0; i < ARRAYSIZE(cert_name); i++) {
@@ -741,9 +751,8 @@ LONG ValidateSignature(HWND hDlg, const char* path)
 	}
 	if (i >= ARRAYSIZE(cert_name)) {
 		uprintf("PKI: Signature '%s' is unexpected...", signature_name);
-		if ((hDlg == INVALID_HANDLE_VALUE) || (MessageBoxExU(hDlg,
-			lmprintf(MSG_285, signature_name), lmprintf(MSG_283),
-			MB_YESNO | MB_ICONWARNING | MB_IS_RTL, selected_langid) != IDYES))
+		if ((hDlg == INVALID_HANDLE_VALUE) || (Notification(MB_YESNO | MB_ICONWARNING,
+			lmprintf(MSG_283), lmprintf(MSG_285, signature_name)) != IDYES))
 			return TRUST_E_EXPLICIT_DISTRUST;
 	}
 
@@ -792,18 +801,18 @@ LONG ValidateSignature(HWND hDlg, const char* path)
 			}
 		}
 		if ((r != ERROR_SUCCESS) && (force_update < 2))
-			MessageBoxExU(hDlg, lmprintf(MSG_300), lmprintf(MSG_299), MB_OK | MB_ICONERROR | MB_IS_RTL, selected_langid);
+			Notification(MB_OK | MB_ICONERROR, lmprintf(MSG_299), lmprintf(MSG_300));
 		break;
 	case TRUST_E_NOSIGNATURE:
 		// Should already have been reported, but since we have a custom message for it...
 		uprintf("PKI: File does not appear to be signed: %s", WinPKIErrorString());
 		if (hDlg != INVALID_HANDLE_VALUE)
-			MessageBoxExU(hDlg, lmprintf(MSG_284), lmprintf(MSG_283), MB_OK | MB_ICONERROR | MB_IS_RTL, selected_langid);
+			Notification(MB_OK | MB_ICONERROR, lmprintf(MSG_283), lmprintf(MSG_284));
 		break;
 	default:
 		uprintf("PKI: Failed to validate signature: %s", WinPKIErrorString());
 		if (hDlg != INVALID_HANDLE_VALUE)
-			MessageBoxExU(hDlg, lmprintf(MSG_240), lmprintf(MSG_283), MB_OK | MB_ICONERROR | MB_IS_RTL, selected_langid);
+			Notification(MB_OK | MB_ICONERROR, lmprintf(MSG_283), lmprintf(MSG_240));
 		break;
 	}
 
