@@ -28,8 +28,8 @@
 #include <accctrl.h>
 #include <aclapi.h>
 
-#include "re.h"
 #include "rufus.h"
+#include "cregex.h"
 #include "missing.h"
 #include "resource.h"
 #include "msapi_utf8.h"
@@ -82,8 +82,8 @@ BOOL htab_create(uint32_t nel, htab_table* htab)
 	if (htab == NULL) {
 		return FALSE;
 	}
-	if_not_assert(htab->table == NULL) {
-		uprintf("Warning: htab_create() was called with a non empty table");
+	if_assert_fails(htab->table == NULL) {
+		uprintf("WARNING: htab_create() was called with a non empty table");
 		return FALSE;
 	}
 
@@ -198,7 +198,7 @@ uint32_t htab_hash(char* str, htab_table* htab)
 	// Not found => New entry
 
 	// If the table is full return an error
-	if_not_assert(htab->filled < htab->size) {
+	if_assert_fails(htab->filled < htab->size) {
 		uprintf("Hash table is full (%d entries)", htab->size);
 		return 0;
 	}
@@ -796,21 +796,20 @@ DWORD GetResourceSize(HMODULE module, char* name, char* type, const char* desc)
 
 // Run a console command, with optional redirection of stdout and stderr to our log
 // as well as optional progress reporting if msg is not 0.
-DWORD RunCommandWithProgress(const char* cmd, const char* dir, BOOL log, int msg)
+DWORD RunCommandWithProgress(const char* cmd, const char* dir, BOOL log, int msg, const char* pattern)
 {
-	DWORD i, ret, dwRead, dwAvail, dwPipeSize = 4096;
+	DWORD ret, dwRead, dwAvail, dwPipeSize = 4096;
 	STARTUPINFOA si = { 0 };
 	PROCESS_INFORMATION pi = { 0 };
 	SECURITY_ATTRIBUTES sa = { sizeof(SECURITY_ATTRIBUTES), NULL, TRUE };
 	HANDLE hOutputRead = INVALID_HANDLE_VALUE, hOutputWrite = INVALID_HANDLE_VALUE;
-	int match_length;
 	static char* output;
-	// For detecting typical dism.exe commandline progress report of type:
-	// "\r[====                       8.0%                           ]\r\n"
-	re_t pattern = re_compile("\\s*\\[[= ]+[\\d\\.]+%[= ]+\\]\\s*");
+	cregex_node_t* node = NULL;
+	cregex_program_t* program = NULL;
+	char* matches[REGEX_VM_MAX_MATCHES];
 
 	si.cb = sizeof(si);
-	if (log) {
+	if (msg != 0 || log) {
 		// NB: The size of a pipe is a suggestion, NOT an absolute guarantee
 		// This means that you may get a pipe of 4K even if you requested 1K
 		if (!CreatePipe(&hOutputRead, &hOutputWrite, &sa, dwPipeSize)) {
@@ -831,8 +830,18 @@ DWORD RunCommandWithProgress(const char* cmd, const char* dir, BOOL log, int msg
 		goto out;
 	}
 
-	if (log || msg != 0) {
-		if (msg != 0)
+	if (msg != 0) {
+		node = cregex_parse(pattern);
+		if (node != NULL) {
+			program = cregex_compile_node(node);
+			cregex_parse_free(node);
+		}
+		if (node == NULL || program == NULL)
+			uprintf("Internal error: Failed to parse '%s'", pattern);
+	}
+
+	if (program != NULL || log) {
+		if (program != NULL)
 			UpdateProgressWithInfoInit(NULL, FALSE);
 		while (1) {
 			// Check for user cancel
@@ -859,24 +868,15 @@ DWORD RunCommandWithProgress(const char* cmd, const char* dir, BOOL log, int msg
 					output = malloc(dwAvail + 1);
 					if ((output != NULL) && (ReadFile(hOutputRead, output, dwAvail, &dwRead, NULL)) && (dwRead != 0)) {
 						output[dwAvail] = 0;
-						// Process a commandline progress bar into a percentage
-						if ((msg != 0) && (re_matchp(pattern, output, &match_length) != -1)) {
+						// Process a commandline progress into a percentage
+						if (program != NULL && cregex_program_run(program, output, (const char**)matches, ARRAYSIZE(matches)) > 0 &&
+							matches[2] != NULL && matches[3] != NULL) {
+							// matches[2] is for the first group
+							// matches[3] is for the end of the first group
+							matches[3][0] = '\0';
 							float f = 0.0f;
-							i = 0;
-next_progress_line:
-							for (; (i < dwAvail) && (output[i] < '0' || output[i] > '9'); i++);
-							IGNORE_RETVAL(sscanf(&output[i], "%f*", &f));
+							IGNORE_RETVAL(sscanf(matches[2], "%f", &f));
 							UpdateProgressWithInfo(OP_FORMAT, msg, (uint64_t)(f * 100.0f), 100 * 100ULL);
-							// Go to next line
-							while ((++i < dwAvail) && (output[i] != '\n') && (output[i] != '\r'));
-							while ((++i < dwAvail) && ((output[i] == '\n') || (output[i] == '\r')));
-							// Print additional lines, if any
-							if (i < dwAvail) {
-								// Might have two consecutive progress lines in our buffer
-								if (re_matchp(pattern, &output[i], &match_length) != -1)
-									goto next_progress_line;
-								uprintf("%s", &output[i]);
-							}
 						} else if (log) {
 							// output may contain a '%' so don't feed it as a naked format string
 							uprintf("%s", output);
@@ -890,13 +890,13 @@ next_progress_line:
 			Sleep(100);
 		};
 	} else {
-		// TODO: Detect user cancellation here?
 		switch (WaitForSingleObject(pi.hProcess, 1800000)) {
 		case WAIT_TIMEOUT:
 			uprintf("Command did not terminate within timeout duration");
 			break;
 		case WAIT_OBJECT_0:
-			uprintf("Command was terminated by user");
+			if (IS_ERROR(ErrorStatus) && (SCODE_CODE(ErrorStatus) == ERROR_CANCELLED))
+				uprintf("Command was terminated by user");
 			break;
 		default:
 			uprintf("Error while waiting for command to be terminated: %s", WindowsErrorString());
@@ -910,6 +910,7 @@ next_progress_line:
 	CloseHandle(pi.hThread);
 
 out:
+	cregex_compile_free(program);
 	safe_closehandle(hOutputWrite);
 	safe_closehandle(hOutputRead);
 	return ret;
@@ -1115,10 +1116,10 @@ BOOL SetThreadAffinity(DWORD_PTR* thread_affinity, size_t num_threads)
 			thread_affinity[i] |= affinity & (-1LL * affinity);
 			affinity ^= affinity & (-1LL * affinity);
 		}
-		uuprintf("  thr_%d:\t%s", i, printbitslz(thread_affinity[i]));
+		uuprintf("  thr_%llu:\t%s", i, printbitslz(thread_affinity[i]));
 		thread_affinity[num_threads - 1] ^= thread_affinity[i];
 	}
-	uuprintf("  thr_%d:\t%s", i, printbitslz(thread_affinity[i]));
+	uuprintf("  thr_%llu:\t%s", i, printbitslz(thread_affinity[i]));
 	return TRUE;
 }
 
@@ -1215,7 +1216,7 @@ BOOL MountRegistryHive(const HKEY key, const char* pszHiveName, const char* pszH
 	LSTATUS status;
 	HANDLE token = INVALID_HANDLE_VALUE;
 
-	if_not_assert((key == HKEY_LOCAL_MACHINE) || (key == HKEY_USERS))
+	if_assert_fails((key == HKEY_LOCAL_MACHINE) || (key == HKEY_USERS))
 		return FALSE;
 
 	if (!OpenProcessToken(GetCurrentProcess(), TOKEN_ADJUST_PRIVILEGES, &token)) {
@@ -1247,7 +1248,7 @@ BOOL UnmountRegistryHive(const HKEY key, const char* pszHiveName)
 {
 	LSTATUS status;
 
-	if_not_assert((key == HKEY_LOCAL_MACHINE) || (key == HKEY_USERS))
+	if_assert_fails((key == HKEY_LOCAL_MACHINE) || (key == HKEY_USERS))
 		return FALSE;
 
 	status = RegUnLoadKeyA(key, pszHiveName);
