@@ -618,7 +618,7 @@ BOOL WriteFileWithRetry(HANDLE hFile, LPCVOID lpBuffer, DWORD nNumberOfBytesToWr
 	// Need to get the current file pointer in case we need to retry
 	readFilePointer = SetFilePointerEx(hFile, liZero, &liFilePointer, FILE_CURRENT);
 	if (!readFilePointer)
-		uprintf("Warning: Could not read file pointer %s", WindowsErrorString());
+		uprintf("WARNING: Could not read file pointer %s", WindowsErrorString());
 
 	if (nNumRetries == 0)
 		nNumRetries = 1;
@@ -634,7 +634,7 @@ BOOL WriteFileWithRetry(HANDLE hFile, LPCVOID lpBuffer, DWORD nNumberOfBytesToWr
 				return TRUE;
 			// Some large drives return 0, even though all the data was written - See github #787 */
 			if (large_drive && (*lpNumberOfBytesWritten == 0)) {
-				uprintf("Warning: Possible short write");
+				uprintf("WARNING: Possible short write");
 				return TRUE;
 			}
 			uprintf("Wrote %d bytes but requested %d", *lpNumberOfBytesWritten, nNumberOfBytesToWrite);
@@ -908,8 +908,7 @@ uint32_t ResolveDllAddress(dll_resolver_t* resolver)
 	}
 
 	// Download the PDB from Microsoft's symbol servers
-	if (MessageBoxExU(hMainDialog, lmprintf(MSG_345), lmprintf(MSG_115),
-		MB_YESNO | MB_ICONWARNING | MB_IS_RTL, selected_langid) != IDYES)
+	if (Notification(MB_YESNO | MB_ICONWARNING, lmprintf(MSG_115), lmprintf(MSG_345)) != IDYES)
 		goto out;
 	static_sprintf(path, "%s\\%s", temp_dir, info->PdbName);
 	static_sprintf(url, "http://msdl.microsoft.com/download/symbols/%s/%s%x/%s",
@@ -924,7 +923,7 @@ uint32_t ResolveDllAddress(dll_resolver_t* resolver)
 
 	// NB: SymLoadModuleEx() does not load a PDB unless the file has an explicit '.pdb' extension
 	base_address = pfSymLoadModuleEx(hRufus, NULL, path, NULL, DEFAULT_BASE_ADDRESS, 0, NULL, 0);
-	if_not_assert(base_address == DEFAULT_BASE_ADDRESS)
+	if_assert_fails(base_address == DEFAULT_BASE_ADDRESS)
 		goto out;
 	// On Windows 11 ARM64 the following call will return *TWO* different addresses for the same
 	// call, because most Windows DLL's are ARM64X, which means that they are an unholy union of
