@@ -43,6 +43,7 @@
 #include "registry.h"
 #include "settings.h"
 #include "license.h"
+#include "darkmode.h"
 
 /* Globals */
 extern BOOL is_x86_64, appstore_version;
@@ -55,7 +56,7 @@ static char **szDialogItem;
 static int nDialogItems;
 static HWND hUpdatesDlg;
 static const SETTEXTEX friggin_microsoft_unicode_amateurs = { ST_DEFAULT, CP_UTF8 };
-static BOOL notification_is_question;
+static int notification_type;
 static const notification_info* notification_more_info;
 static const char* notification_dont_display_setting;
 static WNDPROC update_original_proc = NULL;
@@ -329,6 +330,7 @@ INT_PTR CALLBACK LicenseCallback(HWND hDlg, UINT message, WPARAM wParam, LPARAM
 	HWND hLicense;
 	switch (message) {
 	case WM_INITDIALOG:
+		SetDarkModeForDlg(hDlg);
 		hLicense = GetDlgItem(hDlg, IDC_LICENSE_TEXT);
 		apply_localization(IDD_LICENSE, hDlg);
 		CenterDialog(hDlg, NULL);
@@ -341,6 +343,7 @@ INT_PTR CALLBACK LicenseCallback(HWND hDlg, UINT message, WPARAM wParam, LPARAM
 		style &= ~(ES_RIGHT);
 		SetWindowLongPtr(hLicense, GWL_STYLE, style);
 		SetDlgItemTextA(hDlg, IDC_LICENSE_TEXT, gplv3);
+		SetDarkModeForChild(hDlg);
 		break;
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
@@ -373,6 +376,7 @@ INT_PTR CALLBACK AboutCallback(HWND hDlg, UINT message, WPARAM wParam, LPARAM lP
 
 	switch (message) {
 	case WM_INITDIALOG:
+		SetDarkModeForDlg(hDlg);
 		resized_already = FALSE;
 		// Execute dialog localization
 		apply_localization(IDD_ABOUTBOX, hDlg);
@@ -407,6 +411,7 @@ INT_PTR CALLBACK AboutCallback(HWND hDlg, UINT message, WPARAM wParam, LPARAM lP
 		// Need to send an explicit SetSel to avoid being positioned at the end of richedit control when tabstop is used
 		SendMessage(hEdit[1], EM_SETSEL, 0, 0);
 		SendMessage(hEdit[0], EM_REQUESTRESIZE, 0, 0);
+		SetDarkModeForChild(hDlg);
 		break;
 	case WM_NOTIFY:
 		switch (((LPNMHDR)lParam)->code) {
@@ -459,6 +464,59 @@ INT_PTR CreateAboutBox(void)
 	return r;
 }
 
+// The warning icon from the OS is *BROKEN* in dark mode at 200% scaling (one of the
+// pixels that should be transparent is set to white), so we fix it. Thanks Microsoft!
+HICON FixWarningIcon(HICON hIcon)
+{
+	void* bits = NULL;
+	ICONINFO info, new_info;
+	BITMAP bmp;
+	BITMAPINFO bmi = { 0 };
+	HBITMAP dib, src_obj, dst_obj;
+	HDC hdc, src_dc, dst_dc;
+	DWORD* pixels;
+
+	GetIconInfo(hIcon, &info);
+	GetObject(info.hbmColor, sizeof(bmp), &bmp);
+	bmi.bmiHeader.biSize = sizeof(BITMAPINFOHEADER);
+	bmi.bmiHeader.biWidth = bmp.bmWidth;
+	bmi.bmiHeader.biHeight = -bmp.bmHeight;
+	bmi.bmiHeader.biPlanes = 1;
+	bmi.bmiHeader.biBitCount = 32;
+	bmi.bmiHeader.biCompression = BI_RGB;
+
+	hdc = GetDC(NULL);
+	dib = CreateDIBSection(hdc, &bmi, DIB_RGB_COLORS, &bits, NULL, 0);
+	ReleaseDC(NULL, hdc);
+	if (dib == NULL)
+		return hIcon;
+	src_dc = CreateCompatibleDC(NULL);
+	dst_dc = CreateCompatibleDC(NULL);
+	src_obj = SelectObject(src_dc, info.hbmColor);
+	dst_obj = SelectObject(dst_dc, dib);
+
+	BitBlt(dst_dc, 0, 0, bmp.bmWidth, bmp.bmHeight, src_dc, 0, 0, SRCCOPY);
+
+	SelectObject(src_dc, src_obj);
+	SelectObject(dst_dc, dst_obj);
+	DeleteDC(src_dc);
+	DeleteDC(dst_dc);
+	pixels = (DWORD*)bits;
+	// Set the problematic pixel, at (13,2), to transparent
+	pixels[2 * bmp.bmWidth + 13] = 0x00000000;
+
+	new_info.fIcon = TRUE;
+	new_info.xHotspot = info.xHotspot;
+	new_info.yHotspot = info.yHotspot;
+	new_info.hbmMask = info.hbmMask;
+	new_info.hbmColor = dib;
+
+	hIcon = CreateIconIndirect(&new_info);
+	DeleteObject(info.hbmColor);
+	DeleteObject(info.hbmMask);
+	return hIcon;
+}
+
 /*
  * We use our own MessageBox for notifications to have greater control (center, no close button, etc)
  */
@@ -479,6 +537,7 @@ INT_PTR CALLBACK NotificationCallback(HWND hDlg, UINT message, WPARAM wParam, LP
 
 	switch (message) {
 	case WM_INITDIALOG:
+		SetDarkModeForDlg(hDlg);
 		// Get the system message box font. See http://stackoverflow.com/a/6057761
 		ncm.cbSize = sizeof(ncm);
 		// If we're compiling with the Vista SDK or later, the NONCLIENTMETRICS struct
@@ -498,6 +557,7 @@ INT_PTR CALLBACK NotificationCallback(HWND hDlg, UINT message, WPARAM wParam, LP
 		SendMessage(GetDlgItem(hDlg, IDNO), WM_SETFONT, (WPARAM)hDlgFont, MAKELPARAM(TRUE, 0));
 		if (bh != 0) {
 			ResizeButtonHeight(hDlg, IDC_MORE_INFO);
+			ResizeButtonHeight(hDlg, IDABORT);
 			ResizeButtonHeight(hDlg, IDYES);
 			ResizeButtonHeight(hDlg, IDNO);
 		}
@@ -506,21 +566,68 @@ INT_PTR CALLBACK NotificationCallback(HWND hDlg, UINT message, WPARAM wParam, LP
 		background_brush = GetSysColorBrush(COLOR_WINDOW);
 		separator_brush = GetSysColorBrush(COLOR_3DLIGHT);
 		buttonface_brush = GetSysColorBrush(COLOR_BTNFACE);
-		SetTitleBarIcon(hDlg);
 		CenterDialog(hDlg, NULL);
-		// Change the default icon
-		if (Static_SetIcon(GetDlgItem(hDlg, IDC_NOTIFICATION_ICON), hMessageIcon) == 0) {
-			uprintf("Could not set dialog icon\n");
+		// Change the default message icon
+		switch (notification_type & 0xF0) {
+		case MB_ICONERROR:
+			hMessageIcon = LoadIcon(NULL, IDI_ERROR);
+			break;
+		case MB_ICONWARNING:
+			hMessageIcon = LoadIcon(NULL, IDI_WARNING);
+			// I really have no idea at what scaling factors Microsoft switches icons.
+			// However, the 200% icon has a jarring white pixel in dark mode, because
+			// Microsoft forgot to set that pixel to transparent, that we need to fix.
+			if (fScale > 1.75f && fScale < 2.5f)
+				hMessageIcon = FixWarningIcon(hMessageIcon);
+			break;
+		case MB_ICONQUESTION:
+			hMessageIcon = LoadIcon(NULL, IDI_QUESTION);
+			break;
+		default:
+			hMessageIcon = LoadIcon(NULL, IDI_INFORMATION);
+			break;
 		}
+		if (Static_SetIcon(GetDlgItem(hDlg, IDC_NOTIFICATION_ICON), hMessageIcon) == 0)
+			uprintf("Could not set the notification dialog icon");
 		// Set the dialog title
-		if (szMessageTitle != NULL) {
+		if (szMessageTitle != NULL)
 			SetWindowTextU(hDlg, szMessageTitle);
-		}
 		// Enable/disable the buttons and set text
-		if (!notification_is_question) {
-			SetWindowTextU(GetDlgItem(hDlg, IDNO), lmprintf(MSG_006));
-		} else {
+		switch (notification_type & 0x0F) {
+		case MB_OKCANCEL:
+			SetWindowTextU(GetDlgItem(hDlg, IDYES), "OK");
+			SetWindowTextU(GetDlgItem(hDlg, IDNO), lmprintf(MSG_007));
 			ShowWindow(GetDlgItem(hDlg, IDYES), SW_SHOW);
+			break;
+		case MB_YESNO:
+			SetWindowTextU(GetDlgItem(hDlg, IDYES), lmprintf(MSG_008));
+			SetWindowTextU(GetDlgItem(hDlg, IDNO), lmprintf(MSG_009));
+			ShowWindow(GetDlgItem(hDlg, IDYES), SW_SHOW);
+			break;
+		case MB_OK:
+			SetWindowTextU(GetDlgItem(hDlg, IDNO), "OK");
+			break;
+		case MB_ABORTRETRYIGNORE:
+			HMODULE hMui;
+			char mui_path[MAX_PATH], button_str[3][64] = { "&Abort", "&Retry", "&Ignore" };
+			// Load the localized button text from user32.dll.mui. 802 = Abort, 803 = Retry, 804 = Ignore
+			static_sprintf(mui_path, "%s\\%s\\user32.dll.mui", sysnative_dir, ToLocaleName(GetUserDefaultUILanguage()));
+			hMui = LoadLibraryU(mui_path);
+			if (hMui != NULL) {
+				LoadStringU(hMui, 802, button_str[0], sizeof(button_str[0]));
+				LoadStringU(hMui, 803, button_str[1], sizeof(button_str[1]));
+				LoadStringU(hMui, 804, button_str[2], sizeof(button_str[2]));
+				FreeLibrary(hMui);
+			}
+			SetWindowTextU(GetDlgItem(hDlg, IDABORT), button_str[0]);
+			SetWindowTextU(GetDlgItem(hDlg, IDYES), button_str[1]);
+			SetWindowTextU(GetDlgItem(hDlg, IDNO), button_str[2]);
+			ShowWindow(GetDlgItem(hDlg, IDABORT), SW_SHOW);
+			ShowWindow(GetDlgItem(hDlg, IDYES), SW_SHOW);
+			break;
+		default:	// One single 'Close' button
+			SetWindowTextU(GetDlgItem(hDlg, IDNO), lmprintf(MSG_006));
+			break;
 		}
 		hCtrl = GetDlgItem(hDlg, IDC_DONT_DISPLAY_AGAIN);
 		if (notification_dont_display_setting != NULL) {
@@ -558,19 +665,19 @@ INT_PTR CALLBACK NotificationCallback(HWND hDlg, UINT message, WPARAM wParam, LP
 			ResizeMoveCtrl(hDlg, GetDlgItem(hDlg, IDC_SELECTION_LINE), 0, dh, 0, 0, 1.0f);
 			ResizeMoveCtrl(hDlg, GetDlgItem(hDlg, IDC_DONT_DISPLAY_AGAIN), 0, dh, 0, 0, 1.0f);
 			ResizeMoveCtrl(hDlg, GetDlgItem(hDlg, IDC_MORE_INFO), 0, dh - cbh, 0, 0, 1.0f);
+			ResizeMoveCtrl(hDlg, GetDlgItem(hDlg, IDABORT), 0, dh - cbh, 0, 0, 1.0f);
 			ResizeMoveCtrl(hDlg, GetDlgItem(hDlg, IDYES), 0, dh -cbh, 0, 0, 1.0f);
 			ResizeMoveCtrl(hDlg, GetDlgItem(hDlg, IDNO), 0, dh -cbh, 0, 0, 1.0f);
 		}
+		SetDarkModeForChild(hDlg);
 		return (INT_PTR)TRUE;
 	case WM_CTLCOLORSTATIC:
 		// Change the background colour for static text and icon
 		SetBkMode((HDC)wParam, TRANSPARENT);
-		if ((HWND)lParam == GetDlgItem(hDlg, IDC_NOTIFICATION_LINE)) {
+		if ((HWND)lParam == GetDlgItem(hDlg, IDC_NOTIFICATION_LINE))
 			return (INT_PTR)separator_brush;
-		}
-		if ((HWND)lParam == GetDlgItem(hDlg, IDC_DONT_DISPLAY_AGAIN)) {
+		if ((HWND)lParam == GetDlgItem(hDlg, IDC_DONT_DISPLAY_AGAIN))
 			return (INT_PTR)buttonface_brush;
-		}
 		return (INT_PTR)background_brush;
 	case WM_NCHITTEST:
 		// Check coordinates to prevent resize actions
@@ -585,19 +692,43 @@ INT_PTR CALLBACK NotificationCallback(HWND hDlg, UINT message, WPARAM wParam, LP
 		safe_delete_object(hDlgFont);
 		break;
 	case WM_COMMAND:
+		// TODO: This is brittle... and I don't think we use it anyway
+		if (LOWORD(wParam) != IDC_MORE_INFO && IsDlgButtonChecked(hDlg, IDC_DONT_DISPLAY_AGAIN) == BST_CHECKED)
+			WriteSettingBool(SETTING_DISABLE_SECURE_BOOT_NOTICE, TRUE);
 		switch (LOWORD(wParam)) {
-		case IDOK:
-		case IDCANCEL:
 		case IDYES:
-		case IDNO:
-			if (IsDlgButtonChecked(hDlg, IDC_DONT_DISPLAY_AGAIN) == BST_CHECKED) {
-				WriteSettingBool(SETTING_DISABLE_SECURE_BOOT_NOTICE, TRUE);
+			// Return IDOK/IDRETRY for calls that expect it
+			switch (notification_type & 0x0F) {
+			case MB_OKCANCEL:
+				wParam = IDOK;
+				break;
+			case MB_ABORTRETRYIGNORE:
+				wParam = IDRETRY;
+				break;
 			}
 			EndDialog(hDlg, LOWORD(wParam));
 			return (INT_PTR)TRUE;
+		case IDNO:
+			// Return IDCANCEL/IDOK/IDIGNORE for calls that expect it
+			switch (notification_type & 0x0F) {
+			case MB_OKCANCEL:
+				wParam = IDCANCEL;
+				break;
+			case MB_OK:
+				wParam = IDOK;
+				break;
+			case MB_ABORTRETRYIGNORE:
+				wParam = IDIGNORE;
+				break;
+			}
+			EndDialog(hDlg, LOWORD(wParam));
+			return (INT_PTR)TRUE;
+		case IDABORT:
+			EndDialog(hDlg, LOWORD(wParam));
+			return (INT_PTR)TRUE;
 		case IDC_MORE_INFO:
 			if (notification_more_info != NULL) {
-				if_not_assert(notification_more_info->callback != NULL)
+				if_assert_fails(notification_more_info->callback != NULL)
 					return (INT_PTR)FALSE;
 				if (notification_more_info->id == MORE_INFO_URL) {
 					ShellExecuteA(hDlg, "open", notification_more_info->url, NULL, NULL, SW_SHOWNORMAL);
@@ -615,9 +746,9 @@ INT_PTR CALLBACK NotificationCallback(HWND hDlg, UINT message, WPARAM wParam, LP
 /*
  * Display a custom notification
  */
-BOOL Notification(int type, const char* dont_display_setting, const notification_info* more_info,  char* title, char* format, ...)
+int NotificationEx(int type, const char* dont_display_setting, const notification_info* more_info, const char* title, const char* format, ...)
 {
-	BOOL ret;
+	INT_PTR ret;
 	va_list args;
 
 	dialog_showing++;
@@ -632,33 +763,13 @@ BOOL Notification(int type, const char* dont_display_setting, const notification
 	va_end(args);
 	szMessageText[LOC_MESSAGE_SIZE - 1] = 0;
 	notification_more_info = more_info;
-	notification_is_question = FALSE;
+	notification_type = type;
 	notification_dont_display_setting = dont_display_setting;
-
-	switch(type) {
-	case MSG_WARNING_QUESTION:
-		notification_is_question = TRUE;
-		// Fall through
-	case MSG_WARNING:
-		hMessageIcon = LoadIcon(NULL, IDI_WARNING);
-		break;
-	case MSG_ERROR:
-		hMessageIcon = LoadIcon(NULL, IDI_ERROR);
-		break;
-	case MSG_QUESTION:
-		hMessageIcon = LoadIcon(NULL, IDI_QUESTION);
-		notification_is_question = TRUE;
-		break;
-	case MSG_INFO:
-	default:
-		hMessageIcon = LoadIcon(NULL, IDI_INFORMATION);
-		break;
-	}
-	ret = (MyDialogBox(hMainInstance, IDD_NOTIFICATION, hMainDialog, NotificationCallback) == IDYES);
+	ret = MyDialogBox(hMainInstance, IDD_NOTIFICATION, hMainDialog, NotificationCallback);
 	safe_free(szMessageText);
 	safe_free(szMessageTitle);
 	dialog_showing--;
-	return ret;
+	return (int)ret;
 }
 
 // We only ever display one selection dialog, so set some params as globals
@@ -690,9 +801,10 @@ static INT_PTR CALLBACK CustomSelectionCallback(HWND hDlg, UINT message, WPARAM
 
 	switch (message) {
 	case WM_INITDIALOG:
+		SetDarkModeForDlg(hDlg);
 		// Don't overflow our max radio button
 		if (nDialogItems > (IDC_SELECTION_CHOICEMAX - IDC_SELECTION_CHOICE1 + 1)) {
-			uprintf("Warning: Too many options requested for Selection (%d vs %d)",
+			uprintf("WARNING: Too many options requested for Selection (%d vs %d)",
 				nDialogItems, IDC_SELECTION_CHOICEMAX - IDC_SELECTION_CHOICE1);
 			nDialogItems = IDC_SELECTION_CHOICEMAX - IDC_SELECTION_CHOICE1;
 		}
@@ -796,6 +908,7 @@ static INT_PTR CALLBACK CustomSelectionCallback(HWND hDlg, UINT message, WPARAM
 		// Set the default selection
 		for (i = 0, m = 1; i < nDialogItems; i++, m <<= 1)
 			Button_SetCheck(GetDlgItem(hDlg, IDC_SELECTION_CHOICE1 + i), (m & selection_dialog_mask) ? BST_CHECKED : BST_UNCHECKED);
+		SetDarkModeForChild(hDlg);
 		return (INT_PTR)TRUE;
 	case WM_CTLCOLORSTATIC:
 		// Change the background colour for static text and icon
@@ -883,9 +996,10 @@ INT_PTR CALLBACK ListCallback(HWND hDlg, UINT message, WPARAM wParam, LPARAM lPa
 
 	switch (message) {
 	case WM_INITDIALOG:
+		SetDarkModeForDlg(hDlg);
 		// Don't overflow our max radio button
 		if (nDialogItems > (IDC_LIST_ITEMMAX - IDC_LIST_ITEM1 + 1)) {
-			uprintf("Warning: Too many items requested for List (%d vs %d)",
+			uprintf("WARNING: Too many items requested for List (%d vs %d)",
 				nDialogItems, IDC_LIST_ITEMMAX - IDC_LIST_ITEM1);
 			nDialogItems = IDC_LIST_ITEMMAX - IDC_LIST_ITEM1;
 		}
@@ -941,6 +1055,7 @@ INT_PTR CALLBACK ListCallback(HWND hDlg, UINT message, WPARAM wParam, LPARAM lPa
 		ResizeMoveCtrl(hDlg, GetDlgItem(hDlg, IDCANCEL), 0, dh, 0, 0, 1.0f);
 		ResizeButtonHeight(hDlg, IDOK);
 		ResizeButtonHeight(hDlg, IDCANCEL);
+		SetDarkModeForChild(hDlg);
 		return (INT_PTR)TRUE;
 	case WM_CTLCOLORSTATIC:
 		// Change the background colour for static text and icon
@@ -1023,7 +1138,7 @@ INT_PTR CALLBACK TooltipCallback(HWND hDlg, UINT message, WPARAM wParam, LPARAM
 #ifdef _DEBUG
 	// comctl32 causes issues if the tooltips are not being manipulated from the same thread as their parent controls
 	if (GetCurrentThreadId() != MainThreadId)
-		uprintf("Warning: Tooltip callback is being called from wrong thread");
+		uprintf("WARNING: Tooltip callback is being called from wrong thread");
 #endif
 	return CallWindowProc(ttlist[i].original_proc, hDlg, message, wParam, lParam);
 }
@@ -1063,6 +1178,7 @@ BOOL CreateTooltip(HWND hControl, const char* message, int duration)
 	if (ttlist[i].hTip == NULL) {
 		return FALSE;
 	}
+	SetDarkTheme(ttlist[i].hTip);
 	ttlist[i].hCtrl = hControl;
 
 	// Subclass the tooltip to handle multiline
@@ -1291,6 +1407,7 @@ INT_PTR CALLBACK UpdateCallback(HWND hDlg, UINT message, WPARAM wParam, LPARAM l
 
 	switch (message) {
 	case WM_INITDIALOG:
+		SetDarkModeForDlg(hDlg);
 		resized_already = FALSE;
 		hUpdatesDlg = hDlg;
 		apply_localization(IDD_UPDATE_POLICY, hDlg);
@@ -1338,6 +1455,7 @@ INT_PTR CALLBACK UpdateCallback(HWND hDlg, UINT message, WPARAM wParam, LPARAM l
 		SendMessage(hPolicy, EM_SETEVENTMASK, 0, ENM_LINK|ENM_REQUESTRESIZE);
 		SendMessageA(hPolicy, EM_SETBKGNDCOLOR, 0, (LPARAM)GetSysColor(COLOR_BTNFACE));
 		SendMessage(hPolicy, EM_REQUESTRESIZE, 0, 0);
+		SetDarkModeForChild(hDlg);
 		break;
 	case WM_NOTIFY:
 		if ((((LPNMHDR)lParam)->code == EN_REQUESTRESIZE) && (!resized_already)) {
@@ -1519,7 +1637,7 @@ BOOL SetUpdateCheck(void)
 #endif
 			more_info.id = IDD_UPDATE_POLICY;
 			more_info.callback = UpdateCallback;
-			enable_updates = Notification(MSG_QUESTION, NULL, &more_info, lmprintf(MSG_004), lmprintf(MSG_005));
+			enable_updates = (NotificationEx(MB_ICONQUESTION | MB_YESNO, NULL, &more_info, lmprintf(MSG_004), lmprintf(MSG_005)) == IDYES);
 #if !defined(_DEBUG)
 		}
 #endif
@@ -1561,6 +1679,37 @@ void CreateStaticFont(HDC hDC, HFONT* hFont, BOOL underlined)
 	*hFont = CreateFontIndirect(&lf);
 }
 
+void SetHyperLinkFont(HWND hWnd, HDC hDC, HFONT* hFont, BOOL underlined)
+{
+	static BOOL use_static_font = FALSE;
+	LOGFONT lf = { 0 };
+	HFONT hFontTmp = NULL;
+
+	if (*hFont == NULL) {
+		hFontTmp = (HFONT)SendMessage(hWnd, WM_GETFONT, 0, 0);
+		if (hFontTmp != NULL) {
+			GetObject(hFontTmp, sizeof(LOGFONT), &lf);
+			use_static_font = FALSE;
+		} else {
+			NONCLIENTMETRICS ncm = { 0 };
+			ncm.cbSize = sizeof(NONCLIENTMETRICS);
+			if (SystemParametersInfo(SPI_GETNONCLIENTMETRICS, sizeof(NONCLIENTMETRICS), &ncm, 0)) {
+				lf = ncm.lfStatusFont;
+				use_static_font = FALSE;
+			} else {
+				CreateStaticFont(hDC, hFont, underlined);
+				use_static_font = TRUE;
+			}
+		}
+		if (!use_static_font) {
+			lf.lfUnderline = underlined;
+			*hFont = CreateFontIndirect(&lf);
+		}
+	}
+	if (!use_static_font)
+		SendMessage(hWnd, WM_SETFONT, (WPARAM)*hFont, TRUE);
+}
+
 /*
  * Work around the limitations of edit control, to display a hand cursor for hyperlinks
  * NB: The LTEXT control must have SS_NOTIFY attribute for this to work
@@ -1587,7 +1736,7 @@ INT_PTR CALLBACK NewVersionCallback(HWND hDlg, UINT message, WPARAM wParam, LPAR
 	char cmdline[] = APPLICATION_NAME " -w 150";
 	static char* filepath = NULL;
 	static int download_status = 0;
-	static HFONT hyperlink_font = NULL;
+	static HFONT hHyperlinkFont = NULL;
 	static HANDLE hThread = NULL;
 	HWND hNotes;
 	LONG err;
@@ -1598,6 +1747,7 @@ INT_PTR CALLBACK NewVersionCallback(HWND hDlg, UINT message, WPARAM wParam, LPAR
 
 	switch (message) {
 	case WM_INITDIALOG:
+		SetDarkModeForDlg(hDlg);
 		apply_localization(IDD_NEW_VERSION, hDlg);
 		download_status = 0;
 		SetTitleBarIcon(hDlg);
@@ -1618,18 +1768,20 @@ INT_PTR CALLBACK NewVersionCallback(HWND hDlg, UINT message, WPARAM wParam, LPAR
 		if (update.download_url == NULL)
 			EnableWindow(GetDlgItem(hDlg, IDC_DOWNLOAD), FALSE);
 		ResizeButtonHeight(hDlg, IDCANCEL);
+		SetDarkModeForChild(hDlg);
+		SubclassProgressBarControl(GetDlgItem(hDlg, IDC_PROGRESS));
+		SetHyperLinkFont(GetDlgItem(hDlg, IDC_WEBSITE), (HDC)wParam, &hHyperlinkFont, TRUE);
 		break;
 	case WM_CTLCOLORSTATIC:
 		if ((HWND)lParam != GetDlgItem(hDlg, IDC_WEBSITE))
 			return FALSE;
 		// Change the font for the hyperlink
 		SetBkMode((HDC)wParam, TRANSPARENT);
-		CreateStaticFont((HDC)wParam, &hyperlink_font, TRUE);
-		SelectObject((HDC)wParam, hyperlink_font);
-		SetTextColor((HDC)wParam, RGB(0,0,125));	// DARK_BLUE
+		SelectObject((HDC)wParam, hHyperlinkFont);
+		SetTextColor((HDC)wParam, GetSysColor(COLOR_HOTLIGHT));
 		return (INT_PTR)GetSysColorBrush(COLOR_BTNFACE);
 	case WM_NCDESTROY:
-		safe_delete_object(hyperlink_font);
+		safe_delete_object(hHyperlinkFont);
 		break;
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
@@ -1975,11 +2127,11 @@ void SetAlertPromptMessages(void)
 		// 4126 = "Format disk" (button)
 		if (LoadStringU(hMui, 4125, title_str[0], sizeof(title_str[0])) <= 0) {
 			static_strcpy(title_str[0], "Microsoft Windows");
-			uprintf("Warning: Could not locate localized format prompt title string in '%s': %s", mui_path, WindowsErrorString());
+			uprintf("WARNING: Could not locate localized format prompt title string in '%s': %s", mui_path, WindowsErrorString());
 		}
 		if (LoadStringU(hMui, 4126, button_str, sizeof(button_str)) <= 0) {
 			static_strcpy(button_str, "Format disk");
-			uprintf("Warning: Could not locate localized format prompt button string in '%s': %s", mui_path, WindowsErrorString());
+			uprintf("WARNING: Could not locate localized format prompt button string in '%s': %s", mui_path, WindowsErrorString());
 		}
 		FreeLibrary(hMui);
 	}
