@@ -25,16 +25,26 @@
 #pragma once
 
 // Progress bar colors
-#define PROGRESS_BAR_NORMAL_TEXT_COLOR		RGB(0x00, 0x00, 0x00)
-#define PROGRESS_BAR_INVERTED_TEXT_COLOR	RGB(0xFF, 0xFF, 0xFF)
-#define PROGRESS_BAR_BACKGROUND_COLOR		RGB(0xE6, 0xE6, 0xE6)
-#define PROGRESS_BAR_BOX_COLOR				RGB(0xBC, 0xBC, 0xBC)
-#define PROGRESS_BAR_NORMAL_COLOR			RGB(0x06, 0xB0, 0x25)
-#define PROGRESS_BAR_PAUSED_COLOR			RGB(0xDA, 0xCB, 0x26)
-#define PROGRESS_BAR_ERROR_COLOR			RGB(0xDA, 0x26, 0x26)
+#define PROGRESS_BAR_NORMAL_TEXT_COLOR				RGB(0x00, 0x00, 0x00)
+#define PROGRESS_BAR_INVERTED_TEXT_COLOR			RGB(0xFF, 0xFF, 0xFF)
+#define PROGRESS_BAR_BACKGROUND_COLOR				RGB(0xE6, 0xE6, 0xE6)
+#define PROGRESS_BAR_BOX_COLOR						RGB(0xBC, 0xBC, 0xBC)
+#define PROGRESS_BAR_NORMAL_COLOR					RGB(0x06, 0xB0, 0x25)
+#define PROGRESS_BAR_PAUSED_COLOR					RGB(0xDA, 0xCB, 0x26)
+#define PROGRESS_BAR_ERROR_COLOR					RGB(0xDA, 0x26, 0x26)
 
 // Toolbar icons main color
-#define TOOLBAR_ICON_COLOR					RGB(0x29, 0x80, 0xB9)
+#define TOOLBAR_ICON_COLOR							RGB(0x29, 0x80, 0xB9)
+
+// Dark Mode Colors
+#define DARKMODE_TOOLBAR_ICON_COLOR					RGB(0xFF, 0xD7, 0x00)
+#define DARKMODE_NORMAL_TEXT_COLOR					RGB(0xE0, 0xE0, 0xE0)
+#define DARKMODE_DISABLED_TEXT_COLOR				RGB(0x80, 0x80, 0x80)
+#define DARKMODE_NORMAL_DIALOG_BACKGROUND_COLOR		RGB(0x20, 0x20, 0x20)
+#define DARKMODE_NORMAL_CONTROL_BACKGROUND_COLOR	RGB(0x38, 0x38, 0x38)
+#define DARKMODE_HOT_CONTROL_BACKGROUND_COLOR		RGB(0x45, 0x45, 0x45)
+#define DARKMODE_NORMAL_CONTROL_EDGE_COLOR			RGB(0x64, 0x64, 0x64)
+#define DARKMODE_HOT_CONTROL_EDGE_COLOR				RGB(0x9B, 0x9B, 0x9B)
 
 // Toolbar default style
 #define TOOLBAR_STYLE						( WS_CHILD | WS_TABSTOP | WS_VISIBLE | \
